/***************************************************************************//**
* \file Console_BOOT.h
* \version 3.20
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_Console_H)
#define CY_SCB_BOOT_Console_H

#include "Console_PVT.h"

#if (Console_SCB_MODE_I2C_INC)
    #include "Console_I2C.h"
#endif /* (Console_SCB_MODE_I2C_INC) */

#if (Console_SCB_MODE_EZI2C_INC)
    #include "Console_EZI2C.h"
#endif /* (Console_SCB_MODE_EZI2C_INC) */

#if (Console_SCB_MODE_SPI_INC || Console_SCB_MODE_UART_INC)
    #include "Console_SPI_UART.h"
#endif /* (Console_SCB_MODE_SPI_INC || Console_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define Console_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Console) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (Console_SCB_MODE_I2C_INC)
    #define Console_I2C_BTLDR_COMM_ENABLED     (Console_BTLDR_COMM_ENABLED && \
                                                            (Console_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Console_I2C_SLAVE_CONST))
#else
     #define Console_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (Console_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (Console_SCB_MODE_EZI2C_INC)
    #define Console_EZI2C_BTLDR_COMM_ENABLED   (Console_BTLDR_COMM_ENABLED && \
                                                         Console_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define Console_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (Console_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (Console_SCB_MODE_SPI_INC)
    #define Console_SPI_BTLDR_COMM_ENABLED     (Console_BTLDR_COMM_ENABLED && \
                                                            (Console_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             Console_SPI_SLAVE_CONST))
#else
        #define Console_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (Console_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (Console_SCB_MODE_UART_INC)
       #define Console_UART_BTLDR_COMM_ENABLED    (Console_BTLDR_COMM_ENABLED && \
                                                            (Console_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (Console_UART_RX_DIRECTION && \
                                                              Console_UART_TX_DIRECTION)))
#else
     #define Console_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (Console_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define Console_BTLDR_COMM_MODE_ENABLED    (Console_I2C_BTLDR_COMM_ENABLED   || \
                                                     Console_SPI_BTLDR_COMM_ENABLED   || \
                                                     Console_EZI2C_BTLDR_COMM_ENABLED || \
                                                     Console_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void Console_I2CCyBtldrCommStart(void);
    void Console_I2CCyBtldrCommStop (void);
    void Console_I2CCyBtldrCommReset(void);
    cystatus Console_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Console_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (Console_SCB_MODE_I2C_CONST_CFG)
        #define Console_CyBtldrCommStart   Console_I2CCyBtldrCommStart
        #define Console_CyBtldrCommStop    Console_I2CCyBtldrCommStop
        #define Console_CyBtldrCommReset   Console_I2CCyBtldrCommReset
        #define Console_CyBtldrCommRead    Console_I2CCyBtldrCommRead
        #define Console_CyBtldrCommWrite   Console_I2CCyBtldrCommWrite
    #endif /* (Console_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void Console_EzI2CCyBtldrCommStart(void);
    void Console_EzI2CCyBtldrCommStop (void);
    void Console_EzI2CCyBtldrCommReset(void);
    cystatus Console_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Console_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (Console_SCB_MODE_EZI2C_CONST_CFG)
        #define Console_CyBtldrCommStart   Console_EzI2CCyBtldrCommStart
        #define Console_CyBtldrCommStop    Console_EzI2CCyBtldrCommStop
        #define Console_CyBtldrCommReset   Console_EzI2CCyBtldrCommReset
        #define Console_CyBtldrCommRead    Console_EzI2CCyBtldrCommRead
        #define Console_CyBtldrCommWrite   Console_EzI2CCyBtldrCommWrite
    #endif /* (Console_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void Console_SpiCyBtldrCommStart(void);
    void Console_SpiCyBtldrCommStop (void);
    void Console_SpiCyBtldrCommReset(void);
    cystatus Console_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Console_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (Console_SCB_MODE_SPI_CONST_CFG)
        #define Console_CyBtldrCommStart   Console_SpiCyBtldrCommStart
        #define Console_CyBtldrCommStop    Console_SpiCyBtldrCommStop
        #define Console_CyBtldrCommReset   Console_SpiCyBtldrCommReset
        #define Console_CyBtldrCommRead    Console_SpiCyBtldrCommRead
        #define Console_CyBtldrCommWrite   Console_SpiCyBtldrCommWrite
    #endif /* (Console_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void Console_UartCyBtldrCommStart(void);
    void Console_UartCyBtldrCommStop (void);
    void Console_UartCyBtldrCommReset(void);
    cystatus Console_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus Console_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (Console_SCB_MODE_UART_CONST_CFG)
        #define Console_CyBtldrCommStart   Console_UartCyBtldrCommStart
        #define Console_CyBtldrCommStop    Console_UartCyBtldrCommStop
        #define Console_CyBtldrCommReset   Console_UartCyBtldrCommReset
        #define Console_CyBtldrCommRead    Console_UartCyBtldrCommRead
        #define Console_CyBtldrCommWrite   Console_UartCyBtldrCommWrite
    #endif /* (Console_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_BTLDR_COMM_ENABLED)
    #if (Console_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void Console_CyBtldrCommStart(void);
        void Console_CyBtldrCommStop (void);
        void Console_CyBtldrCommReset(void);
        cystatus Console_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus Console_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (Console_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Console)
        #define CyBtldrCommStart    Console_CyBtldrCommStart
        #define CyBtldrCommStop     Console_CyBtldrCommStop
        #define CyBtldrCommReset    Console_CyBtldrCommReset
        #define CyBtldrCommWrite    Console_CyBtldrCommWrite
        #define CyBtldrCommRead     Console_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Console) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Console_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define Console_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define Console_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define Console_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define Console_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef Console_SPI_BYTE_TO_BYTE
    #define Console_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef Console_UART_BYTE_TO_BYTE
    #define Console_UART_BYTE_TO_BYTE  (175u)
#endif /* Console_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_Console_H) */


/* [] END OF FILE */
