/***************************************************************************//**
* \file Console_PINS.h
* \version 3.20
*
* \brief
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_Console_H)
#define CY_SCB_PINS_Console_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define Console_REMOVE_RX_WAKE_SDA_MOSI_PIN  (1u)
#define Console_REMOVE_RX_SDA_MOSI_PIN      (1u)
#define Console_REMOVE_TX_SCL_MISO_PIN      (1u)
#define Console_REMOVE_CTS_SCLK_PIN      (1u)
#define Console_REMOVE_RTS_SS0_PIN      (1u)
#define Console_REMOVE_SS1_PIN                 (1u)
#define Console_REMOVE_SS2_PIN                 (1u)
#define Console_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define Console_REMOVE_I2C_PINS                (1u)
#define Console_REMOVE_SPI_MASTER_PINS         (1u)
#define Console_REMOVE_SPI_MASTER_SCLK_PIN     (1u)
#define Console_REMOVE_SPI_MASTER_MOSI_PIN     (1u)
#define Console_REMOVE_SPI_MASTER_MISO_PIN     (1u)
#define Console_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define Console_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define Console_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define Console_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define Console_REMOVE_SPI_SLAVE_PINS          (1u)
#define Console_REMOVE_SPI_SLAVE_MOSI_PIN      (1u)
#define Console_REMOVE_SPI_SLAVE_MISO_PIN      (1u)
#define Console_REMOVE_UART_TX_PIN             (0u)
#define Console_REMOVE_UART_RX_TX_PIN          (1u)
#define Console_REMOVE_UART_RX_PIN             (0u)
#define Console_REMOVE_UART_RX_WAKE_PIN        (1u)
#define Console_REMOVE_UART_RTS_PIN            (1u)
#define Console_REMOVE_UART_CTS_PIN            (1u)

/* Unconfigured pins */
#define Console_RX_WAKE_SDA_MOSI_PIN (0u == Console_REMOVE_RX_WAKE_SDA_MOSI_PIN)
#define Console_RX_SDA_MOSI_PIN     (0u == Console_REMOVE_RX_SDA_MOSI_PIN)
#define Console_TX_SCL_MISO_PIN     (0u == Console_REMOVE_TX_SCL_MISO_PIN)
#define Console_CTS_SCLK_PIN     (0u == Console_REMOVE_CTS_SCLK_PIN)
#define Console_RTS_SS0_PIN     (0u == Console_REMOVE_RTS_SS0_PIN)
#define Console_SS1_PIN                (0u == Console_REMOVE_SS1_PIN)
#define Console_SS2_PIN                (0u == Console_REMOVE_SS2_PIN)
#define Console_SS3_PIN                (0u == Console_REMOVE_SS3_PIN)

/* Mode defined pins */
#define Console_I2C_PINS               (0u == Console_REMOVE_I2C_PINS)
#define Console_SPI_MASTER_PINS        (0u == Console_REMOVE_SPI_MASTER_PINS)
#define Console_SPI_MASTER_SCLK_PIN    (0u == Console_REMOVE_SPI_MASTER_SCLK_PIN)
#define Console_SPI_MASTER_MOSI_PIN    (0u == Console_REMOVE_SPI_MASTER_MOSI_PIN)
#define Console_SPI_MASTER_MISO_PIN    (0u == Console_REMOVE_SPI_MASTER_MISO_PIN)
#define Console_SPI_MASTER_SS0_PIN     (0u == Console_REMOVE_SPI_MASTER_SS0_PIN)
#define Console_SPI_MASTER_SS1_PIN     (0u == Console_REMOVE_SPI_MASTER_SS1_PIN)
#define Console_SPI_MASTER_SS2_PIN     (0u == Console_REMOVE_SPI_MASTER_SS2_PIN)
#define Console_SPI_MASTER_SS3_PIN     (0u == Console_REMOVE_SPI_MASTER_SS3_PIN)
#define Console_SPI_SLAVE_PINS         (0u == Console_REMOVE_SPI_SLAVE_PINS)
#define Console_SPI_SLAVE_MOSI_PIN     (0u == Console_REMOVE_SPI_SLAVE_MOSI_PIN)
#define Console_SPI_SLAVE_MISO_PIN     (0u == Console_REMOVE_SPI_SLAVE_MISO_PIN)
#define Console_UART_TX_PIN            (0u == Console_REMOVE_UART_TX_PIN)
#define Console_UART_RX_TX_PIN         (0u == Console_REMOVE_UART_RX_TX_PIN)
#define Console_UART_RX_PIN            (0u == Console_REMOVE_UART_RX_PIN)
#define Console_UART_RX_WAKE_PIN       (0u == Console_REMOVE_UART_RX_WAKE_PIN)
#define Console_UART_RTS_PIN           (0u == Console_REMOVE_UART_RTS_PIN)
#define Console_UART_CTS_PIN           (0u == Console_REMOVE_UART_CTS_PIN)


/***************************************
*             Includes
****************************************/

#if (Console_RX_WAKE_SDA_MOSI_PIN)
    #include "Console_uart_rx_wake_i2c_sda_spi_mosi.h"
#endif /* (Console_RX_SDA_MOSI) */

#if (Console_RX_SDA_MOSI_PIN)
    #include "Console_uart_rx_i2c_sda_spi_mosi.h"
#endif /* (Console_RX_SDA_MOSI) */

#if (Console_TX_SCL_MISO_PIN)
    #include "Console_uart_tx_i2c_scl_spi_miso.h"
#endif /* (Console_TX_SCL_MISO) */

#if (Console_CTS_SCLK_PIN)
    #include "Console_uart_cts_spi_sclk.h"
#endif /* (Console_CTS_SCLK) */

#if (Console_RTS_SS0_PIN)
    #include "Console_uart_rts_spi_ss0.h"
#endif /* (Console_RTS_SS0_PIN) */

#if (Console_SS1_PIN)
    #include "Console_spi_ss1.h"
#endif /* (Console_SS1_PIN) */

#if (Console_SS2_PIN)
    #include "Console_spi_ss2.h"
#endif /* (Console_SS2_PIN) */

#if (Console_SS3_PIN)
    #include "Console_spi_ss3.h"
#endif /* (Console_SS3_PIN) */

#if (Console_I2C_PINS)
    #include "Console_scl.h"
    #include "Console_sda.h"
#endif /* (Console_I2C_PINS) */

#if (Console_SPI_MASTER_PINS)
#if (Console_SPI_MASTER_SCLK_PIN)
    #include "Console_sclk_m.h"
#endif /* (Console_SPI_MASTER_SCLK_PIN) */

#if (Console_SPI_MASTER_MOSI_PIN)
    #include "Console_mosi_m.h"
#endif /* (Console_SPI_MASTER_MOSI_PIN) */

#if (Console_SPI_MASTER_MISO_PIN)
    #include "Console_miso_m.h"
#endif /*(Console_SPI_MASTER_MISO_PIN) */
#endif /* (Console_SPI_MASTER_PINS) */

#if (Console_SPI_SLAVE_PINS)
    #include "Console_sclk_s.h"
    #include "Console_ss_s.h"

#if (Console_SPI_SLAVE_MOSI_PIN)
    #include "Console_mosi_s.h"
#endif /* (Console_SPI_SLAVE_MOSI_PIN) */

#if (Console_SPI_SLAVE_MISO_PIN)
    #include "Console_miso_s.h"
#endif /*(Console_SPI_SLAVE_MISO_PIN) */
#endif /* (Console_SPI_SLAVE_PINS) */

#if (Console_SPI_MASTER_SS0_PIN)
    #include "Console_ss0_m.h"
#endif /* (Console_SPI_MASTER_SS0_PIN) */

#if (Console_SPI_MASTER_SS1_PIN)
    #include "Console_ss1_m.h"
#endif /* (Console_SPI_MASTER_SS1_PIN) */

#if (Console_SPI_MASTER_SS2_PIN)
    #include "Console_ss2_m.h"
#endif /* (Console_SPI_MASTER_SS2_PIN) */

#if (Console_SPI_MASTER_SS3_PIN)
    #include "Console_ss3_m.h"
#endif /* (Console_SPI_MASTER_SS3_PIN) */

#if (Console_UART_TX_PIN)
    #include "Console_tx.h"
#endif /* (Console_UART_TX_PIN) */

#if (Console_UART_RX_TX_PIN)
    #include "Console_rx_tx.h"
#endif /* (Console_UART_RX_TX_PIN) */

#if (Console_UART_RX_PIN)
    #include "Console_rx.h"
#endif /* (Console_UART_RX_PIN) */

#if (Console_UART_RX_WAKE_PIN)
    #include "Console_rx_wake.h"
#endif /* (Console_UART_RX_WAKE_PIN) */

#if (Console_UART_RTS_PIN)
    #include "Console_rts.h"
#endif /* (Console_UART_RTS_PIN) */

#if (Console_UART_CTS_PIN)
    #include "Console_cts.h"
#endif /* (Console_UART_CTS_PIN) */


/***************************************
*              Registers
***************************************/

#if (Console_RX_SDA_MOSI_PIN)
    #define Console_RX_SDA_MOSI_HSIOM_REG   (*(reg32 *) Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM)
    #define Console_RX_SDA_MOSI_HSIOM_PTR   ( (reg32 *) Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM)
    
    #define Console_RX_SDA_MOSI_HSIOM_MASK      (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_MASK)
    #define Console_RX_SDA_MOSI_HSIOM_POS       (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_SHIFT)
    #define Console_RX_SDA_MOSI_HSIOM_SEL_GPIO  (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_GPIO)
    #define Console_RX_SDA_MOSI_HSIOM_SEL_I2C   (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_I2C)
    #define Console_RX_SDA_MOSI_HSIOM_SEL_SPI   (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_SPI)
    #define Console_RX_SDA_MOSI_HSIOM_SEL_UART  (Console_uart_rx_i2c_sda_spi_mosi__0__HSIOM_UART)
    
#elif (Console_RX_WAKE_SDA_MOSI_PIN)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_REG   (*(reg32 *) Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_PTR   ( (reg32 *) Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM)
    
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_MASK      (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_MASK)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_POS       (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_SHIFT)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_SEL_GPIO  (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_GPIO)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_SEL_I2C   (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_I2C)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_SEL_SPI   (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_SPI)
    #define Console_RX_WAKE_SDA_MOSI_HSIOM_SEL_UART  (Console_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_UART)    
   
    #define Console_RX_WAKE_SDA_MOSI_INTCFG_REG (*(reg32 *) Console_uart_rx_wake_i2c_sda_spi_mosi__0__INTCFG)
    #define Console_RX_WAKE_SDA_MOSI_INTCFG_PTR ( (reg32 *) Console_uart_rx_wake_i2c_sda_spi_mosi__0__INTCFG)
    #define Console_RX_WAKE_SDA_MOSI_INTCFG_TYPE_POS  (Console_uart_rx_wake_i2c_sda_spi_mosi__SHIFT)
    #define Console_RX_WAKE_SDA_MOSI_INTCFG_TYPE_MASK ((uint32) Console_INTCFG_TYPE_MASK << \
                                                                           Console_RX_WAKE_SDA_MOSI_INTCFG_TYPE_POS)
#else
    /* None of pins Console_RX_SDA_MOSI_PIN or Console_RX_WAKE_SDA_MOSI_PIN present.*/
#endif /* (Console_RX_SDA_MOSI_PIN) */

#if (Console_TX_SCL_MISO_PIN)
    #define Console_TX_SCL_MISO_HSIOM_REG   (*(reg32 *) Console_uart_tx_i2c_scl_spi_miso__0__HSIOM)
    #define Console_TX_SCL_MISO_HSIOM_PTR   ( (reg32 *) Console_uart_tx_i2c_scl_spi_miso__0__HSIOM)
    
    #define Console_TX_SCL_MISO_HSIOM_MASK      (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_MASK)
    #define Console_TX_SCL_MISO_HSIOM_POS       (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_SHIFT)
    #define Console_TX_SCL_MISO_HSIOM_SEL_GPIO  (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_GPIO)
    #define Console_TX_SCL_MISO_HSIOM_SEL_I2C   (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_I2C)
    #define Console_TX_SCL_MISO_HSIOM_SEL_SPI   (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_SPI)
    #define Console_TX_SCL_MISO_HSIOM_SEL_UART  (Console_uart_tx_i2c_scl_spi_miso__0__HSIOM_UART)
#endif /* (Console_TX_SCL_MISO_PIN) */

#if (Console_CTS_SCLK_PIN)
    #define Console_CTS_SCLK_HSIOM_REG   (*(reg32 *) Console_uart_cts_spi_sclk__0__HSIOM)
    #define Console_CTS_SCLK_HSIOM_PTR   ( (reg32 *) Console_uart_cts_spi_sclk__0__HSIOM)
    
    #define Console_CTS_SCLK_HSIOM_MASK      (Console_uart_cts_spi_sclk__0__HSIOM_MASK)
    #define Console_CTS_SCLK_HSIOM_POS       (Console_uart_cts_spi_sclk__0__HSIOM_SHIFT)
    #define Console_CTS_SCLK_HSIOM_SEL_GPIO  (Console_uart_cts_spi_sclk__0__HSIOM_GPIO)
    #define Console_CTS_SCLK_HSIOM_SEL_I2C   (Console_uart_cts_spi_sclk__0__HSIOM_I2C)
    #define Console_CTS_SCLK_HSIOM_SEL_SPI   (Console_uart_cts_spi_sclk__0__HSIOM_SPI)
    #define Console_CTS_SCLK_HSIOM_SEL_UART  (Console_uart_cts_spi_sclk__0__HSIOM_UART)
#endif /* (Console_CTS_SCLK_PIN) */

#if (Console_RTS_SS0_PIN)
    #define Console_RTS_SS0_HSIOM_REG   (*(reg32 *) Console_uart_rts_spi_ss0__0__HSIOM)
    #define Console_RTS_SS0_HSIOM_PTR   ( (reg32 *) Console_uart_rts_spi_ss0__0__HSIOM)
    
    #define Console_RTS_SS0_HSIOM_MASK      (Console_uart_rts_spi_ss0__0__HSIOM_MASK)
    #define Console_RTS_SS0_HSIOM_POS       (Console_uart_rts_spi_ss0__0__HSIOM_SHIFT)
    #define Console_RTS_SS0_HSIOM_SEL_GPIO  (Console_uart_rts_spi_ss0__0__HSIOM_GPIO)
    #define Console_RTS_SS0_HSIOM_SEL_I2C   (Console_uart_rts_spi_ss0__0__HSIOM_I2C)
    #define Console_RTS_SS0_HSIOM_SEL_SPI   (Console_uart_rts_spi_ss0__0__HSIOM_SPI)
#if !(Console_CY_SCBIP_V0 || Console_CY_SCBIP_V1)
    #define Console_RTS_SS0_HSIOM_SEL_UART  (Console_uart_rts_spi_ss0__0__HSIOM_UART)
#endif /* !(Console_CY_SCBIP_V0 || Console_CY_SCBIP_V1) */
#endif /* (Console_RTS_SS0_PIN) */

#if (Console_SS1_PIN)
    #define Console_SS1_HSIOM_REG  (*(reg32 *) Console_spi_ss1__0__HSIOM)
    #define Console_SS1_HSIOM_PTR  ( (reg32 *) Console_spi_ss1__0__HSIOM)
    
    #define Console_SS1_HSIOM_MASK     (Console_spi_ss1__0__HSIOM_MASK)
    #define Console_SS1_HSIOM_POS      (Console_spi_ss1__0__HSIOM_SHIFT)
    #define Console_SS1_HSIOM_SEL_GPIO (Console_spi_ss1__0__HSIOM_GPIO)
    #define Console_SS1_HSIOM_SEL_I2C  (Console_spi_ss1__0__HSIOM_I2C)
    #define Console_SS1_HSIOM_SEL_SPI  (Console_spi_ss1__0__HSIOM_SPI)
#endif /* (Console_SS1_PIN) */

#if (Console_SS2_PIN)
    #define Console_SS2_HSIOM_REG     (*(reg32 *) Console_spi_ss2__0__HSIOM)
    #define Console_SS2_HSIOM_PTR     ( (reg32 *) Console_spi_ss2__0__HSIOM)
    
    #define Console_SS2_HSIOM_MASK     (Console_spi_ss2__0__HSIOM_MASK)
    #define Console_SS2_HSIOM_POS      (Console_spi_ss2__0__HSIOM_SHIFT)
    #define Console_SS2_HSIOM_SEL_GPIO (Console_spi_ss2__0__HSIOM_GPIO)
    #define Console_SS2_HSIOM_SEL_I2C  (Console_spi_ss2__0__HSIOM_I2C)
    #define Console_SS2_HSIOM_SEL_SPI  (Console_spi_ss2__0__HSIOM_SPI)
#endif /* (Console_SS2_PIN) */

#if (Console_SS3_PIN)
    #define Console_SS3_HSIOM_REG     (*(reg32 *) Console_spi_ss3__0__HSIOM)
    #define Console_SS3_HSIOM_PTR     ( (reg32 *) Console_spi_ss3__0__HSIOM)
    
    #define Console_SS3_HSIOM_MASK     (Console_spi_ss3__0__HSIOM_MASK)
    #define Console_SS3_HSIOM_POS      (Console_spi_ss3__0__HSIOM_SHIFT)
    #define Console_SS3_HSIOM_SEL_GPIO (Console_spi_ss3__0__HSIOM_GPIO)
    #define Console_SS3_HSIOM_SEL_I2C  (Console_spi_ss3__0__HSIOM_I2C)
    #define Console_SS3_HSIOM_SEL_SPI  (Console_spi_ss3__0__HSIOM_SPI)
#endif /* (Console_SS3_PIN) */

#if (Console_I2C_PINS)
    #define Console_SCL_HSIOM_REG  (*(reg32 *) Console_scl__0__HSIOM)
    #define Console_SCL_HSIOM_PTR  ( (reg32 *) Console_scl__0__HSIOM)
    
    #define Console_SCL_HSIOM_MASK     (Console_scl__0__HSIOM_MASK)
    #define Console_SCL_HSIOM_POS      (Console_scl__0__HSIOM_SHIFT)
    #define Console_SCL_HSIOM_SEL_GPIO (Console_sda__0__HSIOM_GPIO)
    #define Console_SCL_HSIOM_SEL_I2C  (Console_sda__0__HSIOM_I2C)
    
    #define Console_SDA_HSIOM_REG  (*(reg32 *) Console_sda__0__HSIOM)
    #define Console_SDA_HSIOM_PTR  ( (reg32 *) Console_sda__0__HSIOM)
    
    #define Console_SDA_HSIOM_MASK     (Console_sda__0__HSIOM_MASK)
    #define Console_SDA_HSIOM_POS      (Console_sda__0__HSIOM_SHIFT)
    #define Console_SDA_HSIOM_SEL_GPIO (Console_sda__0__HSIOM_GPIO)
    #define Console_SDA_HSIOM_SEL_I2C  (Console_sda__0__HSIOM_I2C)
#endif /* (Console_I2C_PINS) */

#if (Console_SPI_SLAVE_PINS)
    #define Console_SCLK_S_HSIOM_REG   (*(reg32 *) Console_sclk_s__0__HSIOM)
    #define Console_SCLK_S_HSIOM_PTR   ( (reg32 *) Console_sclk_s__0__HSIOM)
    
    #define Console_SCLK_S_HSIOM_MASK      (Console_sclk_s__0__HSIOM_MASK)
    #define Console_SCLK_S_HSIOM_POS       (Console_sclk_s__0__HSIOM_SHIFT)
    #define Console_SCLK_S_HSIOM_SEL_GPIO  (Console_sclk_s__0__HSIOM_GPIO)
    #define Console_SCLK_S_HSIOM_SEL_SPI   (Console_sclk_s__0__HSIOM_SPI)
    
    #define Console_SS0_S_HSIOM_REG    (*(reg32 *) Console_ss0_s__0__HSIOM)
    #define Console_SS0_S_HSIOM_PTR    ( (reg32 *) Console_ss0_s__0__HSIOM)
    
    #define Console_SS0_S_HSIOM_MASK       (Console_ss0_s__0__HSIOM_MASK)
    #define Console_SS0_S_HSIOM_POS        (Console_ss0_s__0__HSIOM_SHIFT)
    #define Console_SS0_S_HSIOM_SEL_GPIO   (Console_ss0_s__0__HSIOM_GPIO)  
    #define Console_SS0_S_HSIOM_SEL_SPI    (Console_ss0_s__0__HSIOM_SPI)
#endif /* (Console_SPI_SLAVE_PINS) */

#if (Console_SPI_SLAVE_MOSI_PIN)
    #define Console_MOSI_S_HSIOM_REG   (*(reg32 *) Console_mosi_s__0__HSIOM)
    #define Console_MOSI_S_HSIOM_PTR   ( (reg32 *) Console_mosi_s__0__HSIOM)
    
    #define Console_MOSI_S_HSIOM_MASK      (Console_mosi_s__0__HSIOM_MASK)
    #define Console_MOSI_S_HSIOM_POS       (Console_mosi_s__0__HSIOM_SHIFT)
    #define Console_MOSI_S_HSIOM_SEL_GPIO  (Console_mosi_s__0__HSIOM_GPIO)
    #define Console_MOSI_S_HSIOM_SEL_SPI   (Console_mosi_s__0__HSIOM_SPI)
#endif /* (Console_SPI_SLAVE_MOSI_PIN) */

#if (Console_SPI_SLAVE_MISO_PIN)
    #define Console_MISO_S_HSIOM_REG   (*(reg32 *) Console_miso_s__0__HSIOM)
    #define Console_MISO_S_HSIOM_PTR   ( (reg32 *) Console_miso_s__0__HSIOM)
    
    #define Console_MISO_S_HSIOM_MASK      (Console_miso_s__0__HSIOM_MASK)
    #define Console_MISO_S_HSIOM_POS       (Console_miso_s__0__HSIOM_SHIFT)
    #define Console_MISO_S_HSIOM_SEL_GPIO  (Console_miso_s__0__HSIOM_GPIO)
    #define Console_MISO_S_HSIOM_SEL_SPI   (Console_miso_s__0__HSIOM_SPI)
#endif /* (Console_SPI_SLAVE_MISO_PIN) */

#if (Console_SPI_MASTER_MISO_PIN)
    #define Console_MISO_M_HSIOM_REG   (*(reg32 *) Console_miso_m__0__HSIOM)
    #define Console_MISO_M_HSIOM_PTR   ( (reg32 *) Console_miso_m__0__HSIOM)
    
    #define Console_MISO_M_HSIOM_MASK      (Console_miso_m__0__HSIOM_MASK)
    #define Console_MISO_M_HSIOM_POS       (Console_miso_m__0__HSIOM_SHIFT)
    #define Console_MISO_M_HSIOM_SEL_GPIO  (Console_miso_m__0__HSIOM_GPIO)
    #define Console_MISO_M_HSIOM_SEL_SPI   (Console_miso_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_MISO_PIN) */

#if (Console_SPI_MASTER_MOSI_PIN)
    #define Console_MOSI_M_HSIOM_REG   (*(reg32 *) Console_mosi_m__0__HSIOM)
    #define Console_MOSI_M_HSIOM_PTR   ( (reg32 *) Console_mosi_m__0__HSIOM)
    
    #define Console_MOSI_M_HSIOM_MASK      (Console_mosi_m__0__HSIOM_MASK)
    #define Console_MOSI_M_HSIOM_POS       (Console_mosi_m__0__HSIOM_SHIFT)
    #define Console_MOSI_M_HSIOM_SEL_GPIO  (Console_mosi_m__0__HSIOM_GPIO)
    #define Console_MOSI_M_HSIOM_SEL_SPI   (Console_mosi_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_MOSI_PIN) */

#if (Console_SPI_MASTER_SCLK_PIN)
    #define Console_SCLK_M_HSIOM_REG   (*(reg32 *) Console_sclk_m__0__HSIOM)
    #define Console_SCLK_M_HSIOM_PTR   ( (reg32 *) Console_sclk_m__0__HSIOM)
    
    #define Console_SCLK_M_HSIOM_MASK      (Console_sclk_m__0__HSIOM_MASK)
    #define Console_SCLK_M_HSIOM_POS       (Console_sclk_m__0__HSIOM_SHIFT)
    #define Console_SCLK_M_HSIOM_SEL_GPIO  (Console_sclk_m__0__HSIOM_GPIO)
    #define Console_SCLK_M_HSIOM_SEL_SPI   (Console_sclk_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_SCLK_PIN) */

#if (Console_SPI_MASTER_SS0_PIN)
    #define Console_SS0_M_HSIOM_REG    (*(reg32 *) Console_ss0_m__0__HSIOM)
    #define Console_SS0_M_HSIOM_PTR    ( (reg32 *) Console_ss0_m__0__HSIOM)
    
    #define Console_SS0_M_HSIOM_MASK       (Console_ss0_m__0__HSIOM_MASK)
    #define Console_SS0_M_HSIOM_POS        (Console_ss0_m__0__HSIOM_SHIFT)
    #define Console_SS0_M_HSIOM_SEL_GPIO   (Console_ss0_m__0__HSIOM_GPIO)
    #define Console_SS0_M_HSIOM_SEL_SPI    (Console_ss0_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_SS0_PIN) */

#if (Console_SPI_MASTER_SS1_PIN)
    #define Console_SS1_M_HSIOM_REG    (*(reg32 *) Console_ss1_m__0__HSIOM)
    #define Console_SS1_M_HSIOM_PTR    ( (reg32 *) Console_ss1_m__0__HSIOM)
    
    #define Console_SS1_M_HSIOM_MASK       (Console_ss1_m__0__HSIOM_MASK)
    #define Console_SS1_M_HSIOM_POS        (Console_ss1_m__0__HSIOM_SHIFT)
    #define Console_SS1_M_HSIOM_SEL_GPIO   (Console_ss1_m__0__HSIOM_GPIO)
    #define Console_SS1_M_HSIOM_SEL_SPI    (Console_ss1_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_SS1_PIN) */

#if (Console_SPI_MASTER_SS2_PIN)
    #define Console_SS2_M_HSIOM_REG    (*(reg32 *) Console_ss2_m__0__HSIOM)
    #define Console_SS2_M_HSIOM_PTR    ( (reg32 *) Console_ss2_m__0__HSIOM)
    
    #define Console_SS2_M_HSIOM_MASK       (Console_ss2_m__0__HSIOM_MASK)
    #define Console_SS2_M_HSIOM_POS        (Console_ss2_m__0__HSIOM_SHIFT)
    #define Console_SS2_M_HSIOM_SEL_GPIO   (Console_ss2_m__0__HSIOM_GPIO)
    #define Console_SS2_M_HSIOM_SEL_SPI    (Console_ss2_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_SS2_PIN) */

#if (Console_SPI_MASTER_SS3_PIN)
    #define Console_SS3_M_HSIOM_REG    (*(reg32 *) Console_ss3_m__0__HSIOM)
    #define Console_SS3_M_HSIOM_PTR    ( (reg32 *) Console_ss3_m__0__HSIOM)
    
    #define Console_SS3_M_HSIOM_MASK      (Console_ss3_m__0__HSIOM_MASK)
    #define Console_SS3_M_HSIOM_POS       (Console_ss3_m__0__HSIOM_SHIFT)
    #define Console_SS3_M_HSIOM_SEL_GPIO  (Console_ss3_m__0__HSIOM_GPIO)
    #define Console_SS3_M_HSIOM_SEL_SPI   (Console_ss3_m__0__HSIOM_SPI)
#endif /* (Console_SPI_MASTER_SS3_PIN) */

#if (Console_UART_RX_PIN)
    #define Console_RX_HSIOM_REG   (*(reg32 *) Console_rx__0__HSIOM)
    #define Console_RX_HSIOM_PTR   ( (reg32 *) Console_rx__0__HSIOM)
    
    #define Console_RX_HSIOM_MASK      (Console_rx__0__HSIOM_MASK)
    #define Console_RX_HSIOM_POS       (Console_rx__0__HSIOM_SHIFT)
    #define Console_RX_HSIOM_SEL_GPIO  (Console_rx__0__HSIOM_GPIO)
    #define Console_RX_HSIOM_SEL_UART  (Console_rx__0__HSIOM_UART)
#endif /* (Console_UART_RX_PIN) */

#if (Console_UART_RX_WAKE_PIN)
    #define Console_RX_WAKE_HSIOM_REG   (*(reg32 *) Console_rx_wake__0__HSIOM)
    #define Console_RX_WAKE_HSIOM_PTR   ( (reg32 *) Console_rx_wake__0__HSIOM)
    
    #define Console_RX_WAKE_HSIOM_MASK      (Console_rx_wake__0__HSIOM_MASK)
    #define Console_RX_WAKE_HSIOM_POS       (Console_rx_wake__0__HSIOM_SHIFT)
    #define Console_RX_WAKE_HSIOM_SEL_GPIO  (Console_rx_wake__0__HSIOM_GPIO)
    #define Console_RX_WAKE_HSIOM_SEL_UART  (Console_rx_wake__0__HSIOM_UART)
#endif /* (Console_UART_WAKE_RX_PIN) */

#if (Console_UART_CTS_PIN)
    #define Console_CTS_HSIOM_REG   (*(reg32 *) Console_cts__0__HSIOM)
    #define Console_CTS_HSIOM_PTR   ( (reg32 *) Console_cts__0__HSIOM)
    
    #define Console_CTS_HSIOM_MASK      (Console_cts__0__HSIOM_MASK)
    #define Console_CTS_HSIOM_POS       (Console_cts__0__HSIOM_SHIFT)
    #define Console_CTS_HSIOM_SEL_GPIO  (Console_cts__0__HSIOM_GPIO)
    #define Console_CTS_HSIOM_SEL_UART  (Console_cts__0__HSIOM_UART)
#endif /* (Console_UART_CTS_PIN) */

#if (Console_UART_TX_PIN)
    #define Console_TX_HSIOM_REG   (*(reg32 *) Console_tx__0__HSIOM)
    #define Console_TX_HSIOM_PTR   ( (reg32 *) Console_tx__0__HSIOM)
    
    #define Console_TX_HSIOM_MASK      (Console_tx__0__HSIOM_MASK)
    #define Console_TX_HSIOM_POS       (Console_tx__0__HSIOM_SHIFT)
    #define Console_TX_HSIOM_SEL_GPIO  (Console_tx__0__HSIOM_GPIO)
    #define Console_TX_HSIOM_SEL_UART  (Console_tx__0__HSIOM_UART)
#endif /* (Console_UART_TX_PIN) */

#if (Console_UART_RX_TX_PIN)
    #define Console_RX_TX_HSIOM_REG   (*(reg32 *) Console_rx_tx__0__HSIOM)
    #define Console_RX_TX_HSIOM_PTR   ( (reg32 *) Console_rx_tx__0__HSIOM)
    
    #define Console_RX_TX_HSIOM_MASK      (Console_rx_tx__0__HSIOM_MASK)
    #define Console_RX_TX_HSIOM_POS       (Console_rx_tx__0__HSIOM_SHIFT)
    #define Console_RX_TX_HSIOM_SEL_GPIO  (Console_rx_tx__0__HSIOM_GPIO)
    #define Console_RX_TX_HSIOM_SEL_UART  (Console_rx_tx__0__HSIOM_UART)
#endif /* (Console_UART_RX_TX_PIN) */

#if (Console_UART_RTS_PIN)
    #define Console_RTS_HSIOM_REG      (*(reg32 *) Console_rts__0__HSIOM)
    #define Console_RTS_HSIOM_PTR      ( (reg32 *) Console_rts__0__HSIOM)
    
    #define Console_RTS_HSIOM_MASK     (Console_rts__0__HSIOM_MASK)
    #define Console_RTS_HSIOM_POS      (Console_rts__0__HSIOM_SHIFT)    
    #define Console_RTS_HSIOM_SEL_GPIO (Console_rts__0__HSIOM_GPIO)
    #define Console_RTS_HSIOM_SEL_UART (Console_rts__0__HSIOM_UART)    
#endif /* (Console_UART_RTS_PIN) */


/***************************************
*        Registers Constants
***************************************/

/* HSIOM switch values. */ 
#define Console_HSIOM_DEF_SEL      (0x00u)
#define Console_HSIOM_GPIO_SEL     (0x00u)
/* The HSIOM values provided below are valid only for Console_CY_SCBIP_V0 
* and Console_CY_SCBIP_V1. It is not recommended to use them for 
* Console_CY_SCBIP_V2. Use pin name specific HSIOM constants provided 
* above instead for any SCB IP block version.
*/
#define Console_HSIOM_UART_SEL     (0x09u)
#define Console_HSIOM_I2C_SEL      (0x0Eu)
#define Console_HSIOM_SPI_SEL      (0x0Fu)

/* Pins settings index. */
#define Console_RX_WAKE_SDA_MOSI_PIN_INDEX   (0u)
#define Console_RX_SDA_MOSI_PIN_INDEX       (0u)
#define Console_TX_SCL_MISO_PIN_INDEX       (1u)
#define Console_CTS_SCLK_PIN_INDEX       (2u)
#define Console_RTS_SS0_PIN_INDEX       (3u)
#define Console_SS1_PIN_INDEX                  (4u)
#define Console_SS2_PIN_INDEX                  (5u)
#define Console_SS3_PIN_INDEX                  (6u)

/* Pins settings mask. */
#define Console_RX_WAKE_SDA_MOSI_PIN_MASK ((uint32) 0x01u << Console_RX_WAKE_SDA_MOSI_PIN_INDEX)
#define Console_RX_SDA_MOSI_PIN_MASK     ((uint32) 0x01u << Console_RX_SDA_MOSI_PIN_INDEX)
#define Console_TX_SCL_MISO_PIN_MASK     ((uint32) 0x01u << Console_TX_SCL_MISO_PIN_INDEX)
#define Console_CTS_SCLK_PIN_MASK     ((uint32) 0x01u << Console_CTS_SCLK_PIN_INDEX)
#define Console_RTS_SS0_PIN_MASK     ((uint32) 0x01u << Console_RTS_SS0_PIN_INDEX)
#define Console_SS1_PIN_MASK                ((uint32) 0x01u << Console_SS1_PIN_INDEX)
#define Console_SS2_PIN_MASK                ((uint32) 0x01u << Console_SS2_PIN_INDEX)
#define Console_SS3_PIN_MASK                ((uint32) 0x01u << Console_SS3_PIN_INDEX)

/* Pin interrupt constants. */
#define Console_INTCFG_TYPE_MASK           (0x03u)
#define Console_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin Drive Mode constants. */
#define Console_PIN_DM_ALG_HIZ  (0u)
#define Console_PIN_DM_DIG_HIZ  (1u)
#define Console_PIN_DM_OD_LO    (4u)
#define Console_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Return drive mode of the pin */
#define Console_DM_MASK    (0x7u)
#define Console_DM_SIZE    (3u)
#define Console_GET_P4_PIN_DM(reg, pos) \
    ( ((reg) & (uint32) ((uint32) Console_DM_MASK << (Console_DM_SIZE * (pos)))) >> \
                                                              (Console_DM_SIZE * (pos)) )

#if (Console_TX_SCL_MISO_PIN)
    #define Console_CHECK_TX_SCL_MISO_PIN_USED \
                (Console_PIN_DM_ALG_HIZ != \
                    Console_GET_P4_PIN_DM(Console_uart_tx_i2c_scl_spi_miso_PC, \
                                                   Console_uart_tx_i2c_scl_spi_miso_SHIFT))
#endif /* (Console_TX_SCL_MISO_PIN) */

#if (Console_RTS_SS0_PIN)
    #define Console_CHECK_RTS_SS0_PIN_USED \
                (Console_PIN_DM_ALG_HIZ != \
                    Console_GET_P4_PIN_DM(Console_uart_rts_spi_ss0_PC, \
                                                   Console_uart_rts_spi_ss0_SHIFT))
#endif /* (Console_RTS_SS0_PIN) */

/* Set bits-mask in register */
#define Console_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit in the register */
#define Console_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define Console_SET_HSIOM_SEL(reg, mask, pos, sel) Console_SET_REGISTER_BITS(reg, mask, pos, sel)
#define Console_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        Console_SET_REGISTER_BITS(reg, mask, pos, intType)
#define Console_SET_INP_DIS(reg, mask, val) Console_SET_REGISTER_BIT(reg, mask, val)

/* Console_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  Console_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if (Console_CY_SCBIP_V0)
#if (Console_I2C_PINS)
    #define Console_SET_I2C_SCL_DR(val) Console_scl_Write(val)

    #define Console_SET_I2C_SCL_HSIOM_SEL(sel) \
                          Console_SET_HSIOM_SEL(Console_SCL_HSIOM_REG,  \
                                                         Console_SCL_HSIOM_MASK, \
                                                         Console_SCL_HSIOM_POS,  \
                                                         (sel))
    #define Console_WAIT_SCL_SET_HIGH  (0u == Console_scl_Read())

/* Unconfigured SCB: scl signal */
#elif (Console_RX_WAKE_SDA_MOSI_PIN)
    #define Console_SET_I2C_SCL_DR(val) \
                            Console_uart_rx_wake_i2c_sda_spi_mosi_Write(val)

    #define Console_SET_I2C_SCL_HSIOM_SEL(sel) \
                    Console_SET_HSIOM_SEL(Console_RX_WAKE_SDA_MOSI_HSIOM_REG,  \
                                                   Console_RX_WAKE_SDA_MOSI_HSIOM_MASK, \
                                                   Console_RX_WAKE_SDA_MOSI_HSIOM_POS,  \
                                                   (sel))

    #define Console_WAIT_SCL_SET_HIGH  (0u == Console_uart_rx_wake_i2c_sda_spi_mosi_Read())

#elif (Console_RX_SDA_MOSI_PIN)
    #define Console_SET_I2C_SCL_DR(val) \
                            Console_uart_rx_i2c_sda_spi_mosi_Write(val)


    #define Console_SET_I2C_SCL_HSIOM_SEL(sel) \
                            Console_SET_HSIOM_SEL(Console_RX_SDA_MOSI_HSIOM_REG,  \
                                                           Console_RX_SDA_MOSI_HSIOM_MASK, \
                                                           Console_RX_SDA_MOSI_HSIOM_POS,  \
                                                           (sel))

    #define Console_WAIT_SCL_SET_HIGH  (0u == Console_uart_rx_i2c_sda_spi_mosi_Read())

#else
    #define Console_SET_I2C_SCL_DR(val)        do{ /* Does nothing */ }while(0)
    #define Console_SET_I2C_SCL_HSIOM_SEL(sel) do{ /* Does nothing */ }while(0)

    #define Console_WAIT_SCL_SET_HIGH  (0u)
#endif /* (Console_I2C_PINS) */

/* SCB I2C: sda signal */
#if (Console_I2C_PINS)
    #define Console_WAIT_SDA_SET_HIGH  (0u == Console_sda_Read())
/* Unconfigured SCB: sda signal */
#elif (Console_TX_SCL_MISO_PIN)
    #define Console_WAIT_SDA_SET_HIGH  (0u == Console_uart_tx_i2c_scl_spi_miso_Read())
#else
    #define Console_WAIT_SDA_SET_HIGH  (0u)
#endif /* (Console_MOSI_SCL_RX_PIN) */
#endif /* (Console_CY_SCBIP_V0) */

/* Clear UART wakeup source */
#if (Console_RX_SDA_MOSI_PIN)
    #define Console_CLEAR_UART_RX_WAKE_INTR        do{ /* Does nothing */ }while(0)
    
#elif (Console_RX_WAKE_SDA_MOSI_PIN)
    #define Console_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Console_uart_rx_wake_i2c_sda_spi_mosi_ClearInterrupt(); \
            }while(0)

#elif(Console_UART_RX_WAKE_PIN)
    #define Console_CLEAR_UART_RX_WAKE_INTR \
            do{                                      \
                (void) Console_rx_wake_ClearInterrupt(); \
            }while(0)
#else
#endif /* (Console_RX_SDA_MOSI_PIN) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Unconfigured pins */
#define Console_REMOVE_MOSI_SCL_RX_WAKE_PIN    Console_REMOVE_RX_WAKE_SDA_MOSI_PIN
#define Console_REMOVE_MOSI_SCL_RX_PIN         Console_REMOVE_RX_SDA_MOSI_PIN
#define Console_REMOVE_MISO_SDA_TX_PIN         Console_REMOVE_TX_SCL_MISO_PIN
#ifndef Console_REMOVE_SCLK_PIN
#define Console_REMOVE_SCLK_PIN                Console_REMOVE_CTS_SCLK_PIN
#endif /* Console_REMOVE_SCLK_PIN */
#ifndef Console_REMOVE_SS0_PIN
#define Console_REMOVE_SS0_PIN                 Console_REMOVE_RTS_SS0_PIN
#endif /* Console_REMOVE_SS0_PIN */

/* Unconfigured pins */
#define Console_MOSI_SCL_RX_WAKE_PIN   Console_RX_WAKE_SDA_MOSI_PIN
#define Console_MOSI_SCL_RX_PIN        Console_RX_SDA_MOSI_PIN
#define Console_MISO_SDA_TX_PIN        Console_TX_SCL_MISO_PIN
#ifndef Console_SCLK_PIN
#define Console_SCLK_PIN               Console_CTS_SCLK_PIN
#endif /* Console_SCLK_PIN */
#ifndef Console_SS0_PIN
#define Console_SS0_PIN                Console_RTS_SS0_PIN
#endif /* Console_SS0_PIN */

#if (Console_MOSI_SCL_RX_WAKE_PIN)
    #define Console_MOSI_SCL_RX_WAKE_HSIOM_REG     Console_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_WAKE_HSIOM_PTR     Console_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_WAKE_HSIOM_MASK    Console_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_WAKE_HSIOM_POS     Console_RX_WAKE_SDA_MOSI_HSIOM_REG

    #define Console_MOSI_SCL_RX_WAKE_INTCFG_REG    Console_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_WAKE_INTCFG_PTR    Console_RX_WAKE_SDA_MOSI_HSIOM_REG

    #define Console_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS   Console_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK  Console_RX_WAKE_SDA_MOSI_HSIOM_REG
#endif /* (Console_RX_WAKE_SDA_MOSI_PIN) */

#if (Console_MOSI_SCL_RX_PIN)
    #define Console_MOSI_SCL_RX_HSIOM_REG      Console_RX_SDA_MOSI_HSIOM_REG
    #define Console_MOSI_SCL_RX_HSIOM_PTR      Console_RX_SDA_MOSI_HSIOM_PTR
    #define Console_MOSI_SCL_RX_HSIOM_MASK     Console_RX_SDA_MOSI_HSIOM_MASK
    #define Console_MOSI_SCL_RX_HSIOM_POS      Console_RX_SDA_MOSI_HSIOM_POS
#endif /* (Console_MOSI_SCL_RX_PIN) */

#if (Console_MISO_SDA_TX_PIN)
    #define Console_MISO_SDA_TX_HSIOM_REG      Console_TX_SCL_MISO_HSIOM_REG
    #define Console_MISO_SDA_TX_HSIOM_PTR      Console_TX_SCL_MISO_HSIOM_REG
    #define Console_MISO_SDA_TX_HSIOM_MASK     Console_TX_SCL_MISO_HSIOM_REG
    #define Console_MISO_SDA_TX_HSIOM_POS      Console_TX_SCL_MISO_HSIOM_REG
#endif /* (Console_MISO_SDA_TX_PIN_PIN) */

#if (Console_SCLK_PIN)
    #ifndef Console_SCLK_HSIOM_REG
    #define Console_SCLK_HSIOM_REG     Console_CTS_SCLK_HSIOM_REG
    #define Console_SCLK_HSIOM_PTR     Console_CTS_SCLK_HSIOM_PTR
    #define Console_SCLK_HSIOM_MASK    Console_CTS_SCLK_HSIOM_MASK
    #define Console_SCLK_HSIOM_POS     Console_CTS_SCLK_HSIOM_POS
    #endif /* Console_SCLK_HSIOM_REG */
#endif /* (Console_SCLK_PIN) */

#if (Console_SS0_PIN)
    #ifndef Console_SS0_HSIOM_REG
    #define Console_SS0_HSIOM_REG      Console_RTS_SS0_HSIOM_REG
    #define Console_SS0_HSIOM_PTR      Console_RTS_SS0_HSIOM_PTR
    #define Console_SS0_HSIOM_MASK     Console_RTS_SS0_HSIOM_MASK
    #define Console_SS0_HSIOM_POS      Console_RTS_SS0_HSIOM_POS
    #endif /* Console_SS0_HSIOM_REG */
#endif /* (Console_SS0_PIN) */

#define Console_MOSI_SCL_RX_WAKE_PIN_INDEX Console_RX_WAKE_SDA_MOSI_PIN_INDEX
#define Console_MOSI_SCL_RX_PIN_INDEX      Console_RX_SDA_MOSI_PIN_INDEX
#define Console_MISO_SDA_TX_PIN_INDEX      Console_TX_SCL_MISO_PIN_INDEX
#ifndef Console_SCLK_PIN_INDEX
#define Console_SCLK_PIN_INDEX             Console_CTS_SCLK_PIN_INDEX
#endif /* Console_SCLK_PIN_INDEX */
#ifndef Console_SS0_PIN_INDEX
#define Console_SS0_PIN_INDEX              Console_RTS_SS0_PIN_INDEX
#endif /* Console_SS0_PIN_INDEX */

#define Console_MOSI_SCL_RX_WAKE_PIN_MASK Console_RX_WAKE_SDA_MOSI_PIN_MASK
#define Console_MOSI_SCL_RX_PIN_MASK      Console_RX_SDA_MOSI_PIN_MASK
#define Console_MISO_SDA_TX_PIN_MASK      Console_TX_SCL_MISO_PIN_MASK
#ifndef Console_SCLK_PIN_MASK
#define Console_SCLK_PIN_MASK             Console_CTS_SCLK_PIN_MASK
#endif /* Console_SCLK_PIN_MASK */
#ifndef Console_SS0_PIN_MASK
#define Console_SS0_PIN_MASK              Console_RTS_SS0_PIN_MASK
#endif /* Console_SS0_PIN_MASK */

#endif /* (CY_SCB_PINS_Console_H) */


/* [] END OF FILE */
