/***************************************************************************//**
* \file .h
* \version 3.20
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_Console_H)
#define CY_SCB_PVT_Console_H

#include "Console.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define Console_SetI2CExtClkInterruptMode(interruptMask) Console_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define Console_ClearI2CExtClkInterruptSource(interruptMask) Console_CLEAR_INTR_I2C_EC(interruptMask)
#define Console_GetI2CExtClkInterruptSource()                (Console_INTR_I2C_EC_REG)
#define Console_GetI2CExtClkInterruptMode()                  (Console_INTR_I2C_EC_MASK_REG)
#define Console_GetI2CExtClkInterruptSourceMasked()          (Console_INTR_I2C_EC_MASKED_REG)

#if (!Console_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define Console_SetSpiExtClkInterruptMode(interruptMask) \
                                                                Console_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define Console_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                Console_CLEAR_INTR_SPI_EC(interruptMask)
    #define Console_GetExtSpiClkInterruptSource()                 (Console_INTR_SPI_EC_REG)
    #define Console_GetExtSpiClkInterruptMode()                   (Console_INTR_SPI_EC_MASK_REG)
    #define Console_GetExtSpiClkInterruptSourceMasked()           (Console_INTR_SPI_EC_MASKED_REG)
#endif /* (!Console_CY_SCBIP_V1) */

#if(Console_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void Console_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (Console_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (Console_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_Console_CUSTOM_INTR_HANDLER)
    extern cyisraddress Console_customIntrHandler;
#endif /* !defined (CY_REMOVE_Console_CUSTOM_INTR_HANDLER) */
#endif /* (Console_SCB_IRQ_INTERNAL) */

extern Console_BACKUP_STRUCT Console_backup;

#if(Console_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 Console_scbMode;
    extern uint8 Console_scbEnableWake;
    extern uint8 Console_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 Console_mode;
    extern uint8 Console_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * Console_rxBuffer;
    extern uint8   Console_rxDataBits;
    extern uint32  Console_rxBufferSize;

    extern volatile uint8 * Console_txBuffer;
    extern uint8   Console_txDataBits;
    extern uint32  Console_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 Console_numberOfAddr;
    extern uint8 Console_subAddrSize;
#endif /* (Console_SCB_MODE_UNCONFIG_CONST_CFG) */

#if (! (Console_SCB_MODE_I2C_CONST_CFG || \
        Console_SCB_MODE_EZI2C_CONST_CFG))
    extern uint16 Console_IntrTxMask;
#endif /* (! (Console_SCB_MODE_I2C_CONST_CFG || \
              Console_SCB_MODE_EZI2C_CONST_CFG)) */


/***************************************
*        Conditional Macro
****************************************/

#if(Console_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define Console_SCB_MODE_I2C_RUNTM_CFG     (Console_SCB_MODE_I2C      == Console_scbMode)
    #define Console_SCB_MODE_SPI_RUNTM_CFG     (Console_SCB_MODE_SPI      == Console_scbMode)
    #define Console_SCB_MODE_UART_RUNTM_CFG    (Console_SCB_MODE_UART     == Console_scbMode)
    #define Console_SCB_MODE_EZI2C_RUNTM_CFG   (Console_SCB_MODE_EZI2C    == Console_scbMode)
    #define Console_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (Console_SCB_MODE_UNCONFIG == Console_scbMode)

    /* Defines wakeup enable */
    #define Console_SCB_WAKE_ENABLE_CHECK       (0u != Console_scbEnableWake)
#endif /* (Console_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!Console_CY_SCBIP_V1)
    #define Console_SCB_PINS_NUMBER    (7u)
#else
    #define Console_SCB_PINS_NUMBER    (2u)
#endif /* (!Console_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_Console_H) */


/* [] END OF FILE */
