/***************************************************************************//**
* \file Console_SPI_UART_PVT.h
* \version 3.20
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_Console_H)
#define CY_SCB_SPI_UART_PVT_Console_H

#include "Console_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (Console_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  Console_rxBufferHead;
    extern volatile uint32  Console_rxBufferTail;
    
    /**
    * \addtogroup group_globals
    * @{
    */
    
    /** Sets when internal software receive buffer overflow
     *  was occurred.
    */  
    extern volatile uint8   Console_rxBufferOverflow;
    /** @} globals */
#endif /* (Console_INTERNAL_RX_SW_BUFFER_CONST) */

#if (Console_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  Console_txBufferHead;
    extern volatile uint32  Console_txBufferTail;
#endif /* (Console_INTERNAL_TX_SW_BUFFER_CONST) */

#if (Console_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 Console_rxBufferInternal[Console_INTERNAL_RX_BUFFER_SIZE];
#endif /* (Console_INTERNAL_RX_SW_BUFFER) */

#if (Console_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 Console_txBufferInternal[Console_TX_BUFFER_SIZE];
#endif /* (Console_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void Console_SpiPostEnable(void);
void Console_SpiStop(void);

#if (Console_SCB_MODE_SPI_CONST_CFG)
    void Console_SpiInit(void);
#endif /* (Console_SCB_MODE_SPI_CONST_CFG) */

#if (Console_SPI_WAKE_ENABLE_CONST)
    void Console_SpiSaveConfig(void);
    void Console_SpiRestoreConfig(void);
#endif /* (Console_SPI_WAKE_ENABLE_CONST) */

void Console_UartPostEnable(void);
void Console_UartStop(void);

#if (Console_SCB_MODE_UART_CONST_CFG)
    void Console_UartInit(void);
#endif /* (Console_SCB_MODE_UART_CONST_CFG) */

#if (Console_UART_WAKE_ENABLE_CONST)
    void Console_UartSaveConfig(void);
    void Console_UartRestoreConfig(void);
#endif /* (Console_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in Console_SetPins() */
#define Console_UART_RX_PIN_ENABLE    (Console_UART_RX)
#define Console_UART_TX_PIN_ENABLE    (Console_UART_TX)

/* UART RTS and CTS position to be used in  Console_SetPins() */
#define Console_UART_RTS_PIN_ENABLE    (0x10u)
#define Console_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define Console_SpiUartEnableIntRx(intSourceMask)  Console_SetRxInterruptMode(intSourceMask)
#define Console_SpiUartEnableIntTx(intSourceMask)  Console_SetTxInterruptMode(intSourceMask)
uint32  Console_SpiUartDisableIntRx(void);
uint32  Console_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_Console_H) */


/* [] END OF FILE */
